==> selenium-selenium-4.37.0.gh.tar.gz: selenium-selenium-4.37.0/dotnet/src/webdriver/BiDi/BrowsingContext/NavigateCommand.cs <==
// <copyright file="NavigateCommand.cs" company="Selenium Committers">
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
// </copyright>

using OpenQA.Selenium.BiDi.Communication;
using OpenQA.Selenium.BiDi.Communication.Json.Converters;
using System.Text.Json.Serialization;

namespace OpenQA.Selenium.BiDi.BrowsingContext;

internal sealed class NavigateCommand(NavigateParameters @params)
    : Command<NavigateParameters, NavigateResult>(@params, "browsingContext.navigate");

internal sealed record NavigateParameters(BrowsingContext Context, string Url, ReadinessState? Wait) : Parameters;

public sealed class NavigateOptions : CommandOptions
{
    public ReadinessState? Wait { get; set; }
}

[JsonConverter(typeof(CamelCaseEnumConverter<ReadinessState>))]
public enum ReadinessState
{
    None,
    Interactive,
    Complete
}

public record NavigateResult(Navigation? Navigation, string Url) : EmptyResult;

==> selenium-selenium-4.39.0.gh.tar.gz: selenium-selenium-4.39.0/dotnet/src/webdriver/BiDi/BrowsingContext/NavigateCommand.cs <==
// <copyright file="NavigateCommand.cs" company="Selenium Committers">
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
// </copyright>

using OpenQA.Selenium.BiDi.Json.Converters;
using System.Text.Json.Serialization;

namespace OpenQA.Selenium.BiDi.BrowsingContext;

internal sealed class NavigateCommand(NavigateParameters @params)
    : Command<NavigateParameters, NavigateResult>(@params, "browsingContext.navigate");

internal sealed record NavigateParameters(BrowsingContext Context, string Url, ReadinessState? Wait) : Parameters;

public sealed class NavigateOptions : CommandOptions
{
    public ReadinessState? Wait { get; set; }
}

[JsonConverter(typeof(CamelCaseEnumConverter<ReadinessState>))]
public enum ReadinessState
{
    None,
    Interactive,
    Complete
}

public record NavigateResult(Navigation? Navigation, string Url) : EmptyResult;
